@@ -12,7 +12,7 @@ from django.http.request import HttpRequest
 
 from fastadmin.api.exceptions import AdminApiException
 from fastadmin.api.helpers import is_valid_id
-from fastadmin.api.schemas import ActionInputSchema, ExportInputSchema, ListQuerySchema, SignInInputSchema
+from fastadmin.api.schemas import ActionInputSchema, ExportInputSchema, SignInInputSchema
 from fastadmin.api.service import ApiService, get_user_id_from_session_id
 from fastadmin.settings import settings
 
@@ -118,6 +118,36 @@ async def me(request: HttpRequest) -> JsonResponse:
         return JsonResponse({"detail": e.detail}, status=e.status_code)
 
 
+@csrf_exempt
+async def dashboard_widget(request: HttpRequest, model: str) -> JsonResponse:
+    """This method is used to get a dashboard widget data.
+
+    :params model: a dashboard widget model.
+    :params min_x_field: a min x field value.
+    :params max_x_field: a max x field value.
+    :params period_x_field: a period x field value.
+    :return: A list of objects.
+    """
+    if request.method != "GET":
+        return JsonResponse({"error": "Method not allowed"}, status=405)
+    filters = request.GET.dict()
+    min_x_field = filters.get("min_x_field", None)
+    max_x_field = filters.get("max_x_field", None)
+    period_x_field = filters.get("period_x_field", None)
+
+    try:
+        data = await api_service.dashboard_widget(
+            request.COOKIES.get(settings.ADMIN_SESSION_ID_KEY, None),
+            model,
+            min_x_field=min_x_field,
+            max_x_field=max_x_field,
+            period_x_field=period_x_field,
+        )
+        return JsonResponse(data)
+    except AdminApiException as e:
+        return JsonResponse({"detail": e.detail}, status=e.status_code)
+
+
 @csrf_exempt
 async def list(request: HttpRequest, model: str) -> JsonResponse:
     """This method is used to get a list of objects.
@@ -137,30 +167,22 @@ async def list(request: HttpRequest, model: str) -> JsonResponse:
     sort_by = filters.get("sort_by", None)
     offset = filters.get("offset", 0)
     limit = filters.get("limit", 10)
-
-    query_params = ListQuerySchema(
-        **dict(
+    try:
+        objs, total = await api_service.list(
+            request.COOKIES.get(settings.ADMIN_SESSION_ID_KEY, None),
+            model,
             search=search,
             sort_by=sort_by,
             filters=filters,
             offset=offset,
             limit=limit,
         )
-    )
-
-    try:
-        objs, total = await api_service.list(
-            request.COOKIES.get(settings.ADMIN_SESSION_ID_KEY, None),
-            model,
-            **query_params.dict(),
-        )
         return JsonResponse(
             {
                 "total": total,
                 "results": objs,
             }
         )
-
     except AdminApiException as e:
         return JsonResponse({"detail": e.detail}, status=e.status_code)
 
