@@ -54,7 +54,8 @@ class SqlAlchemyMixin:
                     continue
 
             is_m2m = field_type == "MANYTOMANY"
-            is_upload = False
+            w_type, _ = self.formfield_overrides.get(field_name, (None, None))
+            is_upload = w_type == WidgetType.Upload
             if with_m2m is not None and not with_m2m and is_m2m:
                 continue
             if with_m2m is not None and with_m2m and not is_m2m:
@@ -141,6 +142,8 @@ class SqlAlchemyMixin:
                         form_widget_type = WidgetType.Select
                         filter_widget_type = WidgetType.Select
                         filter_widget_props["mode"] = "multiple"
+                case "JSON":
+                    form_widget_type = WidgetType.JsonTextArea
 
             # relations
             if field_type in (
@@ -208,7 +211,7 @@ class SqlAlchemyMixin:
                                 filter_widget_type = WidgetType.AsyncSelect
                                 filter_widget_props["mode"] = "multiple"
 
-            form_widget_type, form_widget_props = self.form_fields_widgets.get(
+            form_widget_type, form_widget_props = self.formfield_overrides.get(
                 field_name, (form_widget_type, form_widget_props)
             )
             fields.append(
